summary refs log tree commit diff
path: root/nixos/release-combined.nix
diff options
context:
space:
mode:
authorSamuel Dionne-Riel <samuel@dionne-riel.com>2018-12-19 21:28:04 -0500
committerSamuel Dionne-Riel <samuel@dionne-riel.com>2018-12-19 22:28:10 -0500
commit42e7e39cd3f3ef654c0484af7ccb9e81735a19ea (patch)
treee679263ac33a4bcf1c65336b942a0ecb7daef034 /nixos/release-combined.nix
parent8ab5ef773b3c33219cad4aa10ce195e44a558934 (diff)
downloadnixpkgs-42e7e39cd3f3ef654c0484af7ccb9e81735a19ea.tar
nixpkgs-42e7e39cd3f3ef654c0484af7ccb9e81735a19ea.tar.gz
nixpkgs-42e7e39cd3f3ef654c0484af7ccb9e81735a19ea.tar.bz2
nixpkgs-42e7e39cd3f3ef654c0484af7ccb9e81735a19ea.tar.lz
nixpkgs-42e7e39cd3f3ef654c0484af7ccb9e81735a19ea.tar.xz
nixpkgs-42e7e39cd3f3ef654c0484af7ccb9e81735a19ea.tar.zst
nixpkgs-42e7e39cd3f3ef654c0484af7ccb9e81735a19ea.zip
nixos/release-combined.nix: Filters failing tests
And filters out JDK which can't be built on aarch64-linux.
Diffstat (limited to 'nixos/release-combined.nix')
-rw-r--r--nixos/release-combined.nix41
1 files changed, 22 insertions, 19 deletions
diff --git a/nixos/release-combined.nix b/nixos/release-combined.nix
index 73f785173c2..429afe2b145 100644
--- a/nixos/release-combined.nix
+++ b/nixos/release-combined.nix
@@ -46,7 +46,9 @@ in rec {
     };
     constituents =
       let
-        all = x: map (system: x.${system}) supportedSystems;
+        # Except for the given systems, return the system-specific constituent
+        except = systems: x: map (system: x.${system}) (pkgs.lib.subtractLists systems supportedSystems);
+        all = x: except [] x;
       in [
         nixos.channel
         (all nixos.dummy)
@@ -63,24 +65,24 @@ in rec {
         nixos.tests.chromium.x86_64-linux or []
         (all nixos.tests.firefox)
         (all nixos.tests.firewall)
-        (all nixos.tests.gnome3)
+        (except ["aarch64-linux"] nixos.tests.gnome3)
         nixos.tests.installer.zfsroot.x86_64-linux or [] # ZFS is 64bit only
-        (all nixos.tests.installer.lvm)
-        (all nixos.tests.installer.luksroot)
-        (all nixos.tests.installer.separateBoot)
-        (all nixos.tests.installer.separateBootFat)
-        (all nixos.tests.installer.simple)
-        (all nixos.tests.installer.simpleLabels)
-        (all nixos.tests.installer.simpleProvided)
-        (all nixos.tests.installer.simpleUefiSystemdBoot)
-        (all nixos.tests.installer.swraid)
-        (all nixos.tests.installer.btrfsSimple)
-        (all nixos.tests.installer.btrfsSubvols)
-        (all nixos.tests.installer.btrfsSubvolDefault)
-        (all nixos.tests.boot.biosCdrom)
-        #(all nixos.tests.boot.biosUsb) # disabled due to issue #15690
-        (all nixos.tests.boot.uefiCdrom)
-        (all nixos.tests.boot.uefiUsb)
+        (except ["aarch64-linux"] nixos.tests.installer.lvm)
+        (except ["aarch64-linux"] nixos.tests.installer.luksroot)
+        (except ["aarch64-linux"] nixos.tests.installer.separateBoot)
+        (except ["aarch64-linux"] nixos.tests.installer.separateBootFat)
+        (except ["aarch64-linux"] nixos.tests.installer.simple)
+        (except ["aarch64-linux"] nixos.tests.installer.simpleLabels)
+        (except ["aarch64-linux"] nixos.tests.installer.simpleProvided)
+        (except ["aarch64-linux"] nixos.tests.installer.simpleUefiSystemdBoot)
+        (except ["aarch64-linux"] nixos.tests.installer.swraid)
+        (except ["aarch64-linux"] nixos.tests.installer.btrfsSimple)
+        (except ["aarch64-linux"] nixos.tests.installer.btrfsSubvols)
+        (except ["aarch64-linux"] nixos.tests.installer.btrfsSubvolDefault)
+        (except ["aarch64-linux"] nixos.tests.boot.biosCdrom)
+        #(except ["aarch64-linux"] nixos.tests.boot.biosUsb) # disabled due to issue #15690
+        (except ["aarch64-linux"] nixos.tests.boot.uefiCdrom)
+        (except ["aarch64-linux"] nixos.tests.boot.uefiUsb)
         (all nixos.tests.boot-stage1)
         (all nixos.tests.hibernate)
         nixos.tests.docker.x86_64-linux or []
@@ -132,7 +134,8 @@ in rec {
 
         nixpkgs.tarball
         (all allSupportedNixpkgs.emacs)
-        (all allSupportedNixpkgs.jdk)
+        # The currently available aarch64 JDK is unfree
+        (except ["aarch64-linux"] allSupportedNixpkgs.jdk)
       ];
   });